@@ -2,6 +2,7 @@ function handler() {
   EVENT_DATA=$1
 
   export EVENT_DATA
+ 
   RESPONSE="$(./main.sh)"
   
   # send to cloudwatch logs
@@ -16,15 +17,12 @@ function onEvent() {
   EVENT_DATA=$1
   echo "onEvent ==> $EVENT_DATA" 1>&2;
   requestType=$(getRequestType $1)
-  if [ $requestType == 'Create' ]; then
-    onCreate $1
-  elif [ $requestType == 'Update' ]; then
-    onUpdate $1
-  elif [ $requestType == 'Delete' ]; then
-    onDelete $1
-  else
-    true
-  fi
+  
+  case $requestType in
+    'Create') onCreate $1 ;;
+    'Update') onUpdate $1 ;;
+    'Delete') onDelete $1 ;;
+  esac
 }
 
 function onCreate() {
